"""Parser performance test

This file provides performance tests for parsing UPPAAL systems.
"""

import time

from bs4 import BeautifulSoup

from uppaal2jetracer.parser.parser import SystemParser


def test_location_parse_speed():
    """
    Test parse speed while increasing location amount.
    """

    system_tag = """<nta>
\t<declaration></declaration>
\t<template>
\t\t<name x="5" y="5">Automaton0</name>
\t\t<init ref="id0"/>
\t\t<location id="id0" x="-544" y="-255">
\t\t</location>
"""
    close_tag = """\t</template>
\t<system>Process0=Automaton0();
system Process0;</system>
</nta>"""

    with open("/home/mmaas/Documents/u2j_data/location_stats.txt", "w", encoding = "utf-8") as f:
        for i in range(1, 5000):
            start = time.time_ns()
            SystemParser.parse(BeautifulSoup(system_tag + close_tag, "lxml-xml"))
            f.write(f"{i}, {time.time_ns() - start}\n")
            print(i)
            system_tag += f"""\t\t<location id="id{i}" x="-544" y="-255">
\t\t</location>"""


def test_transition_parse_speed():
    """
    Test parse speed while increasing location amount.
    """

    system_tag = """<nta>
\t<declaration></declaration>
\t<template>
\t\t<name x="5" y="5">Automaton0</name>
\t\t<init ref="id0"/>
\t\t<location id="id0" x="-544" y="-255">
\t\t</location>
"""
    close_tag = """\t</template>
\t<system>Process0=Automaton0();
system Process0;</system>
</nta>"""

    with open("/home/mmaas/Documents/u2j_data/transition_stats.txt", "w", encoding = "utf-8") as f:
        for i in range(1, 5000):
            start = time.time_ns()
            SystemParser.parse(BeautifulSoup(system_tag + close_tag, "lxml-xml"))
            f.write(f"{i}, {(time.time_ns() - start) / 1000}\n")
            print(i)
            system_tag += """\t\t<transition>
\t\t\t<source ref="id0"/>
\t\t\t<target ref="id0"/>
\t\t\t<nail x="24" y="24"/>
\t\t</transition>"""


def test_complete_graph_parse_speed():
    """
    Test parse speed of complete graphs while increasing location amount.
    """

    system_tag = """<nta>
\t<declaration></declaration>
\t<template>
\t\t<name x="5" y="5">Automaton0</name>
\t\t<init ref="id0"/>
\t\t<location id="id0" x="-544" y="-255">
\t\t</location>
"""

    close_tag = """\t\t<transition id="id0.0">
\t\t\t<source ref="id0"/>
\t\t\t<target ref="id0"/>
\t\t</transition>
\t</template>
\t<system>Process0=Automaton0();
system Process0;</system>
</nta>"""

    with open("/home/mmaas/Documents/u2j_data/complete_graph_stats.txt",
              "w", encoding = "utf-8") as f:
        for i in range(1, 1000):
            start = time.time_ns()
            SystemParser.parse(BeautifulSoup(system_tag + close_tag, "lxml-xml"))
            f.write(f"{i}, {time.time_ns() - start}\n")
            print(i)
            system_tag += f"""\t\t<location id="id{i}" x="-544" y="-255">
\t\t</location>"""
            for j in range(0, i):
                close_tag = f"""\t\t<transition id="id{i}.{j}">
\t\t\t<source ref="id{i}"/>
\t\t\t<target ref="id{j}"/>
\t\t</transition>
\t\t<transition id="id{j}.{i}">
\t\t\t<source ref="id{j}"/>
\t\t\t<target ref="id{i}"/>
\t\t</transition>""" + close_tag
