"""Sockets

This file holds all interactions via socket requests.
"""

import sqlalchemy as sa

from uppaal2jetracer.controller.executor import Executor
from uppaal2jetracer.webinterface.app import socketio, db, app, webhandler
from uppaal2jetracer.webinterface.app.models import Global


STOP_ARG = "stop"


@socketio.on("connect")
def connect(auth: str):
    """
    Event called when a user connects via a socket connection.

    :param auth: The auth key used to verify the user.
    :type auth: str
    :raises ConnectionRefusedError: If the user is not authenticated.
    """

    user = db.session.scalar(
        sa.select(Global).where(Global.id == app.config.get("GLOBAL_ID")))

    if user is None or not user.check_password(auth["token"]):
        raise ConnectionRefusedError("[!] User not Authenticated [!]")

    if app.config.get("SHELL_DEBUG"):
        print("Client connected")


@socketio.on("disconnect")
def disconnect(reason: str):
    """
    Event called when a user disconnects.

    :param reason: The reason for the disconnect.
    :type reason: str
    """

    curr_thread = app.config.get("RUNNING_THREAD")

    if curr_thread is not None and curr_thread.is_alive():
        app.config["RUNNING_THREAD"] = None

    Executor.stop()

    args_list = []

    args_list.append(STOP_ARG)

    webhandler.handle_input(webhandler.version_command_name,
                            args_list, app.config.get("DEBUG_MODE"))

    if app.config.get("SHELL_DEBUG"):
        print("Client disconnected, reason: ", reason)


def update_socket(data: dict):
    """
    Send an update message to the client.

    :param data: The data you wish to send via sockets.
    :type data: dict
    """

    socketio.emit("update", data)
