/**
 * This file holds the event for deleting a project.
 * 
 * @module scripts/events/main/delete_project
 */

import RequestHandler from "../../request_handler.js";
import PageHandler from "../../page_handler.js";
import EventHandler from "../../event_handler.js";

/**
 * Deletes a certain project.
 * 
 * @function delete_project_event
 * 
 * @param {HTMLElement} target            - Is the targeted UI element that was clicked.
 * @param {object} args                   - The data attributes of the targeted element.
 * @param {RequestHandler} requestHandler - The handler for HTTP requests.
 * @param {PageHandler} pageHandler       - The handler for UI updates.
 * @param {EventHandler} eventHandler     - The handler for the events.
 */
function delete_project_event(target, args, requestHandler, pageHandler, eventHandler) {

    let projectName = pageHandler.getProjectName(target);

    requestHandler.GET("/api/current", [], (resCurr) => {

        let wasCurrent = false;

        if (resCurr.type) {

            wasCurrent = resCurr.payload.name == projectName;

        }

        requestHandler.POST("/api/delete", [ "False", projectName ], {}, (res) => {

            if (res.type) {
    
                pageHandler.deleteProject(res.payload, wasCurrent);
                pageHandler.addError(res.message, false);
    
            } else {
    
                pageHandler.addError(res.error);
    
            }
    
            eventHandler.isHandlingEvent = false;
    
        });

    });

}

export default delete_project_event;
