/**
 * This file holds the event for selecting a project.
 * 
 * @module scripts/events/main/select_project
 */

import RequestHandler from "../../request_handler.js";
import PageHandler from "../../page_handler.js";
import EventHandler from "../../event_handler.js";

/**
 * Selects a certain project.
 * 
 * @function select_project_event
 * 
 * @param {HTMLElement} target            - Is the targeted UI element that was clicked.
 * @param {object} args                   - The data attributes of the targeted element.
 * @param {RequestHandler} requestHandler - The handler for HTTP requests.
 * @param {PageHandler} pageHandler       - The handler for UI updates.
 * @param {EventHandler} eventHandler     - The handler for the events.
 */
function select_project_event(target, args, requestHandler, pageHandler, eventHandler) {

    let projectName = pageHandler.getProjectName(target);

    requestHandler.GET("/api/select", [ projectName ], (res) => {

        if (res.type) {

            pageHandler.selectProject(res.payload);
            pageHandler.addError(res.message, false);
            pageHandler.closeProjectsFrame();

        } else {

            pageHandler.addError(res.error);

        }

        eventHandler.isHandlingEvent = false;

    });

}

export default select_project_event;
