/**
 * This file holds the event for closing the settings frame.
 * 
 * @module scripts/events/main/close_settings
 */

import RequestHandler from "../../request_handler.js";
import PageHandler from "../../page_handler.js";
import EventHandler from "../../event_handler.js";

/**
 * Closes the settings frame.
 * 
 * @function close_settings_event
 * 
 * @param {HTMLElement} target            - Is the targeted UI element that was clicked.
 * @param {object} args                   - The data attributes of the targeted element.
 * @param {RequestHandler} requestHandler - The handler for HTTP requests.
 * @param {PageHandler} pageHandler       - The handler for UI updates.
 * @param {EventHandler} eventHandler     - The handler for the events.
 */
function close_settings_event(target, args, requestHandler, pageHandler, eventHandler) {

    pageHandler.closeSettingsFrame();
    eventHandler.isHandlingEvent = false;

}

export default close_settings_event;
