/**
 * This file holds the event for updating the new settings.
 * 
 * @module scripts/events/main/update_settings
 */

import RequestHandler from "../../request_handler.js";
import PageHandler from "../../page_handler.js";
import EventHandler from "../../event_handler.js";

/**
 * Updates the new settings.
 * 
 * @function update_settings_event
 * 
 * @param {HTMLElement} target            - Is the targeted UI element that was clicked.
 * @param {object} args                   - The data attributes of the targeted element.
 * @param {RequestHandler} requestHandler - The handler for HTTP requests.
 * @param {PageHandler} pageHandler       - The handler for UI updates.
 * @param {EventHandler} eventHandler     - The handler for the events.
 */
function update_settings_event(target, args, requestHandler, pageHandler, eventHandler) {

    let newSettings = pageHandler.getSettings();
    let newVersionLimit = newSettings.version_max;

    if (isNaN(newVersionLimit) || !Number.isInteger(parseFloat(newVersionLimit)) || parseFloat(newVersionLimit) < 0) {

        pageHandler.addError(eventHandler.ERROR_FORMAT(eventHandler.NOT_A_NUMBER_ERROR));
        eventHandler.isHandlingEvent = false;

        return;

    }

    let _num = parseInt(newVersionLimit);

    requestHandler.POST("/api/config/limit", [ _num ], {}, (res) => {

        if (res.type) {

            pageHandler.addError(res.message, false);
            pageHandler.closeSettingsFrame();

        } else {

            pageHandler.addError(res.error);

        }

        eventHandler.isHandlingEvent = false;

    });

}

export default update_settings_event;
