/* 
* This file acts as the main entry point for the client logic.
* 
* @module scripts/main
*/

import RequestHandler from "./request_handler.js";
import EventHandler from "./event_handler.js";
import PageHandler from "./page_handler.js";
import SocketHandler from "./socket_handler.js";



window.addEventListener('DOMContentLoaded', () => {

    const requestHandler = new RequestHandler();
    const pageHandler = new PageHandler();
    const eventHandler = new EventHandler(requestHandler, pageHandler);

    const socketHandler = new SocketHandler(requestHandler, pageHandler);
    socketHandler.createConnection();

    document.addEventListener('click', (e) => {

        executeEvent(e.target);

    });

    document.addEventListener('keypress', (e) => {

        let settingsFrame = pageHandler.queryElementsWithDataAttribute(pageHandler.DATA_FRAME_TAG_NAME, 
                                                                       pageHandler.DATA_SETTINGS_FRAME_NAME)[0];

        if (e.key == "Enter" && settingsFrame.classList.contains(pageHandler.FRAME_OPEN_CLASS_NAME)) {

            let saveButton = settingsFrame.querySelector('.button');
            executeEvent(saveButton);

        }

    });

    /**
     * Executes an event based on a user interaction.
     * 
     * @function executeEvent
     * 
     * @param {HTMLElement} target - Is the targeted UI element that was clicked or interacted with.
     */
    function executeEvent(target) {

        let dataAttributes = pageHandler.getDataAttributes(target);
        let eventTag = target.getAttribute("data-event");

        if (eventTag != null) eventHandler.handleEvent(target, eventTag, dataAttributes);

    }

});
