"""Web handler

This file holds the command handler of the webinterface.

The web handler accepts the following commands:

    * parse:    Parse an uppaal system to an executable model.
    * prj:      Access projects which contain versions of parsed uppaal systems.
    * run:      Run a parsed uppaal system.
    * ver:      Access saved versions of parsed uppaal systems.

This file can be imported as a module and contains the following classes:

    * WebHandler: The command handler used explicitly by the webinterface
"""

from typing import List, Tuple

from uppaal2jetracer.command_system import CommandHandler, CommandResult


class WebHandler(CommandHandler):
    """
    A CommandHandler that handles commands for the webinterface.
    """

    def handle_input(self, *args: Tuple) -> CommandResult:
        """
        Handles input from the webinterface.
        """

        return self._execute_command(args[0], args[1], args[2])

    def _execute_command(self,
                         name: str,
                         args: List[str] = None,
                         debug: bool = None) -> CommandResult:
        if debug:
            CommandHandler.activate_debug(self._commands[name].loggers)

        result = self._commands[name].execute(args)

        self.deactivate_debug()

        return result
